@@ -1,4 +1,5 @@
 """Main entry point for program"""
+# pylint: skip-file
 
 import logging
 import sys
@@ -1162,21 +1163,21 @@ def docs(debug):
     set_debug_log_level(debug)
     click.echo(click.style('TODO :-/', fg='yellow',))
 
-@tools.command(short_help='\tUpgrade yojenkins')
-@cli_decorators.debug
-@click.option('--user', type=bool, required=False, is_flag=True, help='Install to the Python user install directory for your platform')
-@click.option('--proxy', type=str, required=False, help='Specify a proxy in the form [user:passwd@]proxy.server:port')
-def upgrade(debug, user, proxy):
-    """Install the latest version of yojenkins. This is a thin wrapper to 'pip install'"""
-    set_debug_log_level(debug)
-    cli_tools.upgrade(user, proxy)
+# @tools.command(short_help='\tUpgrade yojenkins')
+# @cli_decorators.debug
+# @click.option('--user', type=bool, required=False, is_flag=True, help='Install to the Python user install directory for your platform')
+# @click.option('--proxy', type=str, required=False, help='Specify a proxy in the form [user:passwd@]proxy.server:port')
+# def upgrade(debug, user, proxy):
+#     """Install the latest version of yojenkins. This is a thin wrapper to 'pip install'"""
+#     set_debug_log_level(debug)
+#     cli_tools.upgrade(user, proxy)
 
-@tools.command(short_help='\tRemove yojenkins')
-@cli_decorators.debug
-def remove(debug):
-    """Uninstall yojenkins using pip"""
-    set_debug_log_level(debug)
-    cli_tools.remove()
+# @tools.command(short_help='\tRemove yojenkins')
+# @cli_decorators.debug
+# def remove(debug):
+#     """Uninstall yojenkins using pip"""
+#     set_debug_log_level(debug)
+#     cli_tools.remove()
 
 @tools.command(short_help='\tReport a bug')
 @cli_decorators.debug
