@@ -13,16 +13,44 @@ from yojenkins.yo_jenkins.status import Status
 logger = logging.getLogger()
 
 
+def _verify_build_url_get_job_format(build_url: str, job: str) -> bool:
+    """Utility function to verify buld url and determine if job is URL or name
+
+    Args:
+        build_url: Build URL
+        job: Job URL or name
+
+    Returns:
+         True if both are valid, False otherwise
+    """
+    if build_url:
+        if not cu.is_full_url(build_url):
+            click.echo(click.style('The build url not formatted correctly', fg='bright_red', bold=True))
+            sys.exit(1)
+        valid_url_format = True
+    else:
+        valid_url_format = cu.is_full_url(job)
+    return valid_url_format
+
+
 @log_to_history
 def info(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, profile: str, job: str, build_number: int,
          build_url: str, latest: bool) -> None:
     """TODO Docstring
 
     Args:
-        TODO
+        opt_pretty: Option to pretty print the output
+        opt_yaml: Option to output in YAML format
+        opt_xml: Option to output in XML format
+        opt_toml: Option to output in TOML format
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -33,36 +61,26 @@ def info(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, profil
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
-    else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
         data = yj_obj.build.info(build_url=build_url, job_url=job, build_number=build_number, latest=latest)
     else:
         data = yj_obj.build.info(build_url=build_url, job_name=job, build_number=build_number, latest=latest)
-
-    if not data:
-        click.echo(click.style('no build information', fg='bright_red', bold=True))
-        sys.exit(1)
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
 
 @log_to_history
 def status(profile: str, job: str, build_number: int, build_url: str, latest: bool) -> None:
-    """TODO Docstring
+    """Build status text/label
 
     Args:
-        TODO
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -73,25 +91,11 @@ def status(profile: str, job: str, build_number: int, build_url: str, latest: bo
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
-    else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
         data = yj_obj.build.status_text(build_url=build_url, job_url=job, build_number=build_number, latest=latest)
     else:
         data = yj_obj.build.status_text(build_url=build_url, job_name=job, build_number=build_number, latest=latest)
 
-    if not data:
-        click.echo(click.style('No status found', fg='bright_red', bold=True))
-        sys.exit(1)
-
     # Color for output
     if data.upper() in Status.UNKNOWN.value:
         output_fg = 'black'
@@ -110,13 +114,17 @@ def status(profile: str, job: str, build_number: int, build_url: str, latest: bo
 
 @log_to_history
 def abort(profile: str, job: str, build_number: int, build_url: str, latest: bool) -> None:
-    """TODO Docstring
+    """Abort build
 
     Args:
-        TODO
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -127,37 +135,26 @@ def abort(profile: str, job: str, build_number: int, build_url: str, latest: boo
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
-    else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
         data = yj_obj.build.abort(build_url=build_url, job_url=job, build_number=build_number, latest=latest)
     else:
         data = yj_obj.build.abort(build_url=build_url, job_name=job, build_number=build_number, latest=latest)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
-
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
 @log_to_history
 def delete(profile: str, job: str, build_number: int, build_url: str, latest: bool) -> None:
-    """TODO Docstring
+    """Delete build
 
     Args:
-        TODO
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -168,38 +165,32 @@ def delete(profile: str, job: str, build_number: int, build_url: str, latest: bo
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
-    else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
         data = yj_obj.build.delete(build_url=build_url, job_url=job, build_number=build_number, latest=latest)
     else:
         data = yj_obj.build.delete(build_url=build_url, job_name=job, build_number=build_number, latest=latest)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
-
-    click.echo(click.style(f'{data}', fg='bright_green', bold=True))
+    click.echo(click.style('success', fg='bright_green', bold=True))
 
 
 @log_to_history
 def stages(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, profile: str, opt_list: bool, job: str,
            build_number: int, build_url: str, latest: bool) -> None:
-    """TODO Docstring
+    """Get build stages
 
     Args:
-        TODO
+        opt_pretty: Option to pretty print the output
+        opt_yaml: Option to output in YAML format
+        opt_xml: Option to output in XML format
+        opt_toml: Option to output in TOML format
+        profile: The profile/account to use
+        opt_list: Option to list all stages without details
+        job: The job name under which the build is located
+        build_number: The build number
+        build_url: The build URL
+        latest: Option to get the latest build
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -210,17 +201,7 @@ def stages(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, prof
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
-    else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
         data, data_list = yj_obj.build.stage_list(build_url=build_url,
                                                   job_url=job,
                                                   build_number=build_number,
@@ -230,11 +211,6 @@ def stages(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, prof
                                                   job_name=job,
                                                   build_number=build_number,
                                                   latest=latest)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
-
     data = data_list if opt_list else data
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
@@ -242,13 +218,20 @@ def stages(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, prof
 @log_to_history
 def logs(profile: str, job: str, build_number: int, build_url: str, latest: bool, tail: float, download_dir: bool,
          follow: bool) -> None:
-    """TODO Docstring
+    """Get build logs
 
     Args:
-        TODO
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
+        tail: Option to get the last N lines of the log
+        download_dir: Option to download the log to a directory
+        follow: Option to follow the log
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -259,50 +242,39 @@ def logs(profile: str, job: str, build_number: int, build_url: str, latest: bool
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
+        yj_obj.build.logs(build_url=build_url,
+                          job_url=job,
+                          build_number=build_number,
+                          latest=latest,
+                          tail=tail,
+                          download_dir=download_dir,
+                          follow=follow)
     else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
-        data = yj_obj.build.logs(build_url=build_url,
-                                 job_url=job,
-                                 build_number=build_number,
-                                 latest=latest,
-                                 tail=tail,
-                                 download_dir=download_dir,
-                                 follow=follow)
-    else:
-        data = yj_obj.build.logs(build_url=build_url,
-                                 job_name=job,
-                                 build_number=build_number,
-                                 latest=latest,
-                                 tail=tail,
-                                 download_dir=download_dir,
-                                 follow=follow)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
-
+        yj_obj.build.logs(build_url=build_url,
+                          job_name=job,
+                          build_number=build_number,
+                          latest=latest,
+                          tail=tail,
+                          download_dir=download_dir,
+                          follow=follow)
     if download_dir:
         click.echo(click.style('success', fg='bright_green', bold=True))
 
 
 @log_to_history
 def browser(profile: str, job: str, build_number: int, build_url: str, latest: bool) -> None:
-    """TODO Docstring
+    """Open build in web browser
 
     Args:
-        TODO
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -313,35 +285,26 @@ def browser(profile: str, job: str, build_number: int, build_url: str, latest: b
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
+        yj_obj.build.browser_open(build_url=build_url, job_url=job, build_number=build_number, latest=latest)
     else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
-        data = yj_obj.build.browser_open(build_url=build_url, job_url=job, build_number=build_number, latest=latest)
-    else:
-        data = yj_obj.build.browser_open(build_url=build_url, job_name=job, build_number=build_number, latest=latest)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+        yj_obj.build.browser_open(build_url=build_url, job_name=job, build_number=build_number, latest=latest)
 
 
 @log_to_history
 def monitor(profile: str, job: str, build_number: int, build_url: str, latest: bool, sound: bool) -> None:
-    """TODO Docstring
+    """Start monitor UI
 
     Args:
-        TODO
+        profile: The profile/account to use
+        job: The job this build is under
+        build_number: The build number to get info on
+        build_url: The build url to get info on
+        latest: Option to get the latest build
+        sound: Option to play a sound when the build status changes
 
     Returns:
-        TODO
+        None
     """
     if job and not build_number and not latest:
         click.echo(
@@ -352,29 +315,7 @@ def monitor(profile: str, job: str, build_number: int, build_url: str, latest: b
 
     yj_obj = cu.config_yo_jenkins(profile)
 
-    # Verify URLs
-    if build_url:
-        if not cu.is_full_url(build_url):
-            click.echo(click.style('build url not formatted correctly', fg='bright_red', bold=True))
-            sys.exit(1)
-        valid_url_format = True
+    if _verify_build_url_get_job_format(build_url=build_url, job=job):
+        yj_obj.build.monitor(build_url=build_url, job_url=job, build_number=build_number, latest=latest, sound=sound)
     else:
-        valid_url_format = cu.is_full_url(job)
-
-    # Request the data
-    if valid_url_format:
-        data = yj_obj.build.monitor(build_url=build_url,
-                                    job_url=job,
-                                    build_number=build_number,
-                                    latest=latest,
-                                    sound=sound)
-    else:
-        data = yj_obj.build.monitor(build_url=build_url,
-                                    job_name=job,
-                                    build_number=build_number,
-                                    latest=latest,
-                                    sound=sound)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+        yj_obj.build.monitor(build_url=build_url, job_name=job, build_number=build_number, latest=latest, sound=sound)
