@@ -9,6 +9,7 @@ import xmltodict
 
 from yojenkins.cli import cli_utility as cu
 from yojenkins.cli.cli_utility import log_to_history
+from yojenkins.utility.utility import print2
 
 # Getting the logger reference
 logger = logging.getLogger()
@@ -22,17 +23,13 @@ def info(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, profil
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.info(job_url=job)
     else:
         data = yj_obj.job.info(job_name=job)
-
-    if not data:
-        click.echo(click.style('not found', fg='bright_red', bold=True))
-        sys.exit(1)
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
 
@@ -45,7 +42,7 @@ def search(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, prof
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(search_folder):
@@ -58,9 +55,8 @@ def search(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, prof
                                             folder_name=search_folder,
                                             folder_depth=depth,
                                             fullname=fullname)
-
     if not data:
-        click.echo(click.style('not found', fg='bright_red', bold=True))
+        print2("No folders found", color="yellow")
         sys.exit(1)
     data = data_list if opt_list else data
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
@@ -75,17 +71,13 @@ def build_list(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool,
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data, data_list = yj_obj.job.build_list(job_url=job)
     else:
         data, data_list = yj_obj.job.build_list(job_name=job)
-
-    if not data:
-        click.echo(click.style('not found', fg='bright_red', bold=True))
-        sys.exit(1)
     data = data_list if opt_list else data
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
@@ -98,17 +90,13 @@ def build_next(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.build_next_number(job_url=job)
     else:
         data = yj_obj.job.build_next_number(job_name=job)
-
-    if not data:
-        click.echo(click.style('not found', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style(f'{data}', fg='bright_green', bold=True))
 
 
@@ -120,17 +108,13 @@ def build_last(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.build_last_number(job_url=job)
     else:
         data = yj_obj.job.build_last_number(job_name=job)
-
-    if not data:
-        click.echo(click.style('not found', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style(f'{data}', fg='bright_green', bold=True))
 
 
@@ -142,17 +126,13 @@ def build_set(profile: str, job: str, build_number: int) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.build_set_next_number(build_number=build_number, job_url=job)
     else:
         data = yj_obj.job.build_set_next_number(build_number=build_number, job_name=job)
-
-    if not data:
-        click.echo(click.style('failed"', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style(f'{build_number}', fg='bright_green', bold=True))
 
 
@@ -164,17 +144,13 @@ def build_exist(profile: str, job: str, build_number: int) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.build_number_exist(build_number=build_number, job_url=job)
     else:
         data = yj_obj.job.build_number_exist(build_number=build_number, job_name=job)
-
-    if not data:
-        click.echo(click.style('not found', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('true', fg='bright_green', bold=True))
 
 
@@ -186,7 +162,7 @@ def build(profile: str, job: str, parameters: tuple) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
 
@@ -197,10 +173,6 @@ def build(profile: str, job: str, parameters: tuple) -> None:
         data = yj_obj.job.build_trigger(job_url=job, paramters=parameters)
     else:
         data = yj_obj.job.build_trigger(job_name=job, paramters=parameters)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style(f'success. queue number: {data}', fg='bright_green', bold=True))
 
 
@@ -213,19 +185,13 @@ def queue_check(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool,
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data, queue_id = yj_obj.job.in_queue_check(job_url=job)
     else:
         data, queue_id = yj_obj.job.in_queue_check(job_name=job)
-
-    if not data:
-        out = '{}' if not opt_id else '0'
-        click.echo(click.style(out, fg='bright_red', bold=True))
-        sys.exit(1)
-
     if opt_id:
         click.echo(click.style(f'{queue_id}', fg='bright_green', bold=True))
     else:
@@ -240,17 +206,13 @@ def browser(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
-        data = yj_obj.job.browser_open(job_url=job)
+        yj_obj.job.browser_open(job_url=job)
     else:
-        data = yj_obj.job.browser_open(job_name=job)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+        yj_obj.job.browser_open(job_name=job)
 
 
 @log_to_history
@@ -262,7 +224,7 @@ def config(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, opt_
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
@@ -277,11 +239,6 @@ def config(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, opt_
                                                 opt_json=opt_json,
                                                 opt_yaml=opt_yaml,
                                                 opt_toml=opt_toml)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
-
     if not write_success:
         click.echo(click.style('failed to write to file', fg='bright_red', bold=True))
         sys.exit(1)
@@ -302,17 +259,13 @@ def disable(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.disable(job_url=job)
     else:
         data = yj_obj.job.disable(job_name=job)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -324,17 +277,13 @@ def enable(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.enable(job_url=job)
     else:
         data = yj_obj.job.enable(job_name=job)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -346,17 +295,13 @@ def rename(profile: str, job: str, new_name: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.rename(new_name=new_name, job_url=job)
     else:
         data = yj_obj.job.rename(new_name=new_name, job_name=job)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -368,17 +313,13 @@ def delete(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.delete(job_url=job)
     else:
         data = yj_obj.job.delete(job_name=job)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -390,17 +331,13 @@ def wipe(profile: str, job: str) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
         data = yj_obj.job.wipe_workspace(job_url=job)
     else:
         data = yj_obj.job.wipe_workspace(job_name=job)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -412,17 +349,13 @@ def monitor(profile: str, job: str, sound: bool) -> None:
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(job):
-        data = yj_obj.job.monitor(job_url=job, sound=sound)
+        yj_obj.job.monitor(job_url=job, sound=sound)
     else:
-        data = yj_obj.job.monitor(job_name=job, sound=sound)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+        yj_obj.job.monitor(job_name=job, sound=sound)
 
 
 @log_to_history
@@ -433,15 +366,11 @@ def create(profile: str, name: str, folder: str, config_file: str, config_is_jso
         TODO
 
     Returns:
-        TODO
+        None
     """
     yj_obj = cu.config_yo_jenkins(profile)
     if cu.is_full_url(folder):
         data = yj_obj.job.create(name=name, folder_url=folder, config_file=config_file, config_is_json=config_is_json)
     else:
         data = yj_obj.job.create(name=name, folder_name=folder, config_file=config_file, config_is_json=config_is_json)
-
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     click.echo(click.style('success', fg='bright_green', bold=True))
