@@ -3,7 +3,6 @@
 import json
 import logging
 import os
-import sys
 from pathlib import Path
 
 import click
@@ -11,7 +10,13 @@ import click
 from yojenkins.cli import cli_utility as cu
 from yojenkins.cli.cli_utility import log_to_history
 from yojenkins.docker_container import DockerJenkinsServer
-from yojenkins.utility.utility import get_project_dir, get_resource_path
+from yojenkins.utility.utility import (
+    fail_out,
+    failures_out,
+    get_project_dir,
+    get_resource_path,
+    print2,
+)
 from yojenkins.yo_jenkins import Auth, YoJenkins
 
 # Getting the logger reference
@@ -34,9 +39,6 @@ def info(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, profil
         TODO
     """
     data = cu.config_yo_jenkins(profile).server.info()
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
 
@@ -53,9 +55,6 @@ def people(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, prof
         TODO
     """
     data, data_list = cu.config_yo_jenkins(profile).server.people()
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     data = data_list if opt_list else data
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
@@ -77,9 +76,6 @@ def queue(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, profi
         data = yj_obj.server.queue_list()  # TODO: Combine with server_queue_list adding a list argument
     else:
         data = yj_obj.server.queue_info()
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
 
@@ -96,9 +92,6 @@ def plugins(opt_pretty: bool, opt_yaml: bool, opt_xml: bool, opt_toml: bool, pro
         TODO
     """
     data, data_list = cu.config_yo_jenkins(profile).server.plugin_list()
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
     data = data_list if opt_list else data
     cu.standard_out(data, opt_pretty, opt_yaml, opt_xml, opt_toml)
 
@@ -113,10 +106,7 @@ def browser(profile: str) -> None:
     Returns:
         TODO
     """
-    data = cu.config_yo_jenkins(profile).server.browser_open()
-    if not data:
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+    cu.config_yo_jenkins(profile).server.browser_open()
 
 
 @log_to_history
@@ -132,13 +122,9 @@ def reachable(profile: str, timeout: int) -> None:
         TODO
     """
     auth = Auth()
-    if not auth.get_credentials(profile):
-        click.echo(click.style('failed to find any credentials', fg='bright_red', bold=True))
-        sys.exit(1)
-    if not YoJenkins(auth=auth).rest.is_reachable(auth.jenkins_profile['jenkins_server_url'], timeout=timeout):
-        click.echo(click.style('false', fg='bright_red', bold=True))
-        sys.exit(1)
-    click.echo(click.style('true', fg='bright_green', bold=True))
+    auth.get_credentials(profile)
+    YoJenkins(auth=auth).rest.is_reachable(auth.jenkins_profile['jenkins_server_url'], timeout=timeout)
+    click.echo(click.style('success', fg='bright_green', bold=True))
 
 
 @log_to_history
@@ -153,9 +139,7 @@ def quiet(profile: str, off: bool):
     Returns:
         TODO
     """
-    if not cu.config_yo_jenkins(profile).server.quiet(off=off):
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+    cu.config_yo_jenkins(profile).server.quiet(off=off)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -171,9 +155,7 @@ def restart(profile: str, force: bool):
     Returns:
         TODO
     """
-    if not cu.config_yo_jenkins(profile).server.restart(force=force):
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+    cu.config_yo_jenkins(profile).server.restart(force=force)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -189,9 +171,7 @@ def shutdown(profile: str, force: bool):
     Returns:
         TODO
     """
-    if not cu.config_yo_jenkins(profile).server.shutdown(force=force):
-        click.echo(click.style('failed', fg='bright_red', bold=True))
-        sys.exit(1)
+    cu.config_yo_jenkins(profile).server.shutdown(force=force)
     click.echo(click.style('success', fg='bright_green', bold=True))
 
 
@@ -231,45 +211,41 @@ def server_deploy(config_file: str, plugins_file: str, protocol_schema: str, hos
 
     # Initialize docker client
     if not djs.docker_client_init():
-        click.echo(click.style('Failed to connect to local docker client', fg='bright_red', bold=True))
-        sys.exit(1)
+        fail_out('Failed to connect to local docker client')
 
     # Setup the server
     deployed, success = djs.setup()
     if not success:
-        click.echo(click.style('Failed to setup server', fg='bright_red', bold=True))
+        failures = ['Failed to setup containerized server']
         if deployed:
-            click.echo(click.style('Items deployed for partial deployment:', fg='bright_red', bold=True))
-            click.echo(click.style(deployed, fg='bright_red', bold=True))
-        sys.exit(1)
+            failures.append('Items deployed for partial deployment:')
+            failures.append(deployed)
+        failures_out(failures)
 
     # Write current server docker attributes to file
     filepath = os.path.join(Path.home(), CONFIG_DIR_NAME, 'last_deploy_info.json')
     if not filepath:
-        click.echo(click.style('Failed to find yojenkins included data directory', fg='bright_red', bold=True))
-        sys.exit(1)
+        fail_out('Failed to find yojenkins module included data directory')
     logger.debug(f'Writing server deploy information to file: {filepath}')
     try:
         with open(os.path.join(filepath), 'w') as file:
             json.dump(deployed, file, indent=4, sort_keys=True)
-    except PermissionError as error:
-        logger.error(f'Server deployed, however failed to write server deploy information to file: {error}')
-        logger.error('yojenkins resources may have been installed under root or a restricted account')
-        sys.exit(1)
+    except (IOError, PermissionError) as error:
+        failures = [f'Server deployed, however failed to write server deploy information to file: {error}']
+        failures.append('yojenkins resources may have been installed under root or a restricted account')
+        failures_out(failures)
 
     volumes_named = [list(l.values())[0] for l in deployed["volumes"]]
 
-    click.echo(click.style('Successfully created containerized Jenkins server!', fg='bright_green', bold=True))
-    click.echo(click.style(f'   - Docker image:      {deployed["image"]}', fg='bright_green', bold=True))
-    click.echo(click.style(f'   - Docker volumes:    {deployed["container"]}', fg='bright_green', bold=True))
-    click.echo(click.style(f'   - Docker container:  {", ".join(volumes_named)}', fg='bright_green', bold=True))
-    click.echo(click.style(f'   - Deployment file:   {filepath}', fg='bright_green', bold=True))
+    print2('Successfully created containerized Jenkins server!', bold=True, color='green')
+    print2(f'   - Docker image:      {deployed["image"]}', bold=True, color='green')
+    print2(f'   - Docker volumes:    {deployed["container"]}', bold=True, color='green')
+    print2(f'   - Docker container:  {", ".join(volumes_named)}', bold=True, color='green')
+    print2(f'   - Deployment file:   {filepath}', bold=True, color='green')
     click.echo()
-    click.echo(click.style(f'Address:  {deployed["address"]}', fg='bright_green', bold=True))
-    click.echo(click.style(f'Username: {admin_user}', fg='bright_green', bold=True))
-    click.echo(
-        click.style(f'Password: {"*************" if password else "password (default)"}', fg='bright_green',
-                    bold=True))
+    print2(f'Address:  {deployed["address"]}', bold=True, color='green')
+    print2(f'Username: {admin_user}', bold=True, color='green')
+    print2(f'Password: {"*************" if password else "password (default)"}', bold=True, color='green')
 
 
 @log_to_history
@@ -291,13 +267,12 @@ def server_teardown(remove_volume: bool, remove_image: bool):
         with open(os.path.join(filepath), 'r') as file:
             deployed = json.load(file)
         logger.debug(f'Successfully found and loaded server deployment info file: {deployed}')
-    except Exception:
-        click.echo(click.style('Failed to detect a previous server deployment', fg='bright_red', bold=True))
-        click.echo(
-            click.style('If you think there was a previously successfull deployment, use Docker to remove it manually',
-                        fg='bright_red',
-                        bold=True))
-        sys.exit(1)
+    except (FileNotFoundError, FileExistsError):
+        failures = ['Failed to find server deployment info file']
+        failures.append('If you think there was a previously successfull deployment, use Docker to remove it manually')
+        failures_out(failures)
+    except (IOError, PermissionError) as error:
+        fail_out(f'Failed to load previous server deployment info file: {error}')
 
     # Filter out named volumes only
     volumes_named_only = [list(l.values())[0] for l in deployed["volumes"] if 'named' in l]
@@ -309,16 +284,13 @@ def server_teardown(remove_volume: bool, remove_image: bool):
 
     # Initialize docker client
     if not djs.docker_client_init():
-        click.echo(click.style('Failed to connect to local docker client', fg='bright_red', bold=True))
-        sys.exit(1)
+        print2('Failed to connect to local docker client')
 
     # Remove the resources
     if not djs.clean(remove_volume, remove_image):
-        click.echo(click.style('Failed to remove Jenkins server', fg='bright_red', bold=True))
-        sys.exit(1)
+        fail_out('Failed to remove Jenkins server')
 
     # Remove the deployment info file
     os.remove(filepath)
 
-    click.echo(click.style(f'Successfully removed Jenkins server: {deployed["address"]}', fg='bright_green',
-                           bold=True))
+    print2(f'Successfully removed Jenkins server: {deployed["address"]}', bold=True, color='green')
